@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 import sys
 
 from PyQt4 import QtGui
@@ -15,12 +13,12 @@ if __name__ == '__main__':
     mainApp = MainApp()
     mainApp.folderlist.readFilenames()
     
-    readme = mainApp.readReadme()
+#    readme = mainApp.readReadme()
     warning = mainApp.readWarning()
  
     ui = MainWindow(mainApp)
-    ui.txtReadme.setText(readme)
-    ui.txtWarning.setText(warning)
+#    ui.txtReadme.setText(readme)
+    ui.txtWarning.setHtml(warning)
     ui.show()
  
     #Initing application
