@@ -4,7 +4,7 @@
 Module implementing DialogSelectFile.
 """
 
-from PyQt4.QtGui import QDialog
+from PyQt4.QtGui import QDialog,  QAbstractItemView
 from PyQt4.QtCore import pyqtSignature
 
 from Ui_dialogSelectFile import Ui_Dialog
@@ -26,4 +26,12 @@ class DialogSelectFile(QDialog, Ui_Dialog):
         """
         Slot documentation goes here.
         """
-        self.mainApp.setFileName(self.listFile.currentItem().text())
+        if self.listFile.selectionMode() == QAbstractItemView.MultiSelection:
+            items = []
+            for index in xrange(self.listFile.count()):
+                item = self.listFile.item(index)
+                if item.isSelected():
+                    items.append(item.text())
+            self.mainApp.setFileNames(items)
+        else:
+            self.mainApp.setFileName(self.listFile.currentItem().text())
